@@ -1,11 +1,11 @@
 # Copyright (c) OpenMMLab. All rights reserved.
 from .file_client import BaseStorageBackend, FileClient
-from .handlers import BaseFileHandler, JsonHandler, PickleHandler, YamlHandler,CsvHandler
+from .handlers import BaseFileHandler, JsonHandler,JsonsHandler, PickleHandler, YamlHandler,CsvHandler
 from .io import dump, load, register_handler
 from .parse import dict_from_file, list_from_file
 
 __all__ = [
     'BaseStorageBackend', 'FileClient', 'load', 'dump', 'register_handler',
-    'BaseFileHandler', 'JsonHandler', 'PickleHandler', 'YamlHandler','CsvHandler',
+    'BaseFileHandler', 'JsonHandler','JsonsHandler', 'PickleHandler', 'YamlHandler','CsvHandler',
     'list_from_file', 'dict_from_file'
 ]
